Crate beep_telemetry

Crate beep_telemetry 

Telemetry integration for the Beep workspace.

This crate wires up OpenTelemetry (OTLP) tracing and metrics and provides a small public surface used by other crates to initialize telemetry.

Re-exports

pub use telemetry::init;
pub use telemetry::OtelGuard;
pub use domain::models::errors::TelemetryError;

Modules

domain
telemetry
OpenTelemetry setup for tracing and metrics used by the workspace.