Module telemetry

Module telemetry 

OpenTelemetry setup for tracing and metrics used by the workspace.

Public API

Structs

OtelGuard

Functions

init
Initialize telemetry for the application using the provided Config.