OpenTelemetry setup for tracing and metrics used by the workspace.
Public API
init— initialize telemetry and return anOtelGuardOtelGuard::shutdown— gracefully shutdown providers and flush buffered telemetry.
OpenTelemetry setup for tracing and metrics used by the workspace.
Public API
init — initialize telemetry and return an OtelGuardOtelGuard::shutdown — gracefully shutdown providers and flush
buffered telemetry.